<?php

// Exit if accessed directly.
if (!defined('ABSPATH')) {
	exit;
}

//////////////////////////////////////////////////////////////////
// Functions to render conditional styles
//////////////////////////////////////////////////////////////////
$gspb_css_save_method = get_option('gspb_css_save');
function gspb_get_breakpoints()
{

	// defaults breakpoints.
	$gsbp_breakpoints = array(
		'mobile' 	=> 576,
		'tablet' 	=> 768,
		'desktop' =>  992
	);

	if (get_option('gspb_global_settings')) {
		$gsbp_custom_breakpoints = get_option('gspb_global_settings')['breakpoints'];

		if (!empty($gsbp_custom_breakpoints['mobile'])) {
			$gsbp_breakpoints['mobile'] = trim($gsbp_custom_breakpoints['mobile']);
		}

		if (!empty($gsbp_custom_breakpoints['tablet'])) {
			$gsbp_breakpoints['tablet'] = trim($gsbp_custom_breakpoints['tablet']);
		}

		if (!empty($gsbp_custom_breakpoints['desktop'])) {
			$gsbp_breakpoints['desktop'] = trim($gsbp_custom_breakpoints['desktop']);
		}
	}

	return array(
		'mobile' 			=> $gsbp_breakpoints['mobile'],
		'mobile_down' 		=> intval($gsbp_breakpoints['mobile']) - 0.02,
		'tablet' 			=> $gsbp_breakpoints['tablet'],
		'tablet_down' 		=> intval($gsbp_breakpoints['tablet']) - 0.02,
		'desktop' 		=> $gsbp_breakpoints['desktop'],
		'desktop_down'	=> intval($gsbp_breakpoints['desktop']) - 0.02,
	);
}
function gspb_get_final_css($gspb_css_content)
{
	$get_breakpoints = gspb_get_breakpoints();

	if($get_breakpoints['mobile'] != 576){
		$gspb_css_content = str_replace('@media (max-width: 575.98px)', '@media (max-width: '.$get_breakpoints["mobile_down"] .'px)', $gspb_css_content);
		$gspb_css_content = str_replace('@media (min-width: 576px)', '@media (min-width: '.$get_breakpoints["mobile"] .'px)', $gspb_css_content);
	}

	if($get_breakpoints['tablet'] != 768){
		$gspb_css_content = str_replace('and (max-width: 767.98px)', 'and (max-width: '.$get_breakpoints["tablet_down"] .'px)', $gspb_css_content);
		$gspb_css_content = str_replace('@media (min-width: 768px)', '@media (min-width: '.$get_breakpoints["tablet"] .'px)', $gspb_css_content);
	}

	if($get_breakpoints['desktop'] != 992){
		$gspb_css_content = str_replace('and (max-width: 991.98px)', 'and (max-width: '.$get_breakpoints["desktop_down"] .'px)', $gspb_css_content);
		$gspb_css_content = str_replace('@media (min-width: 992px)', '@media (min-width: '.$get_breakpoints["desktop"] .'px)', $gspb_css_content);
	}

	return $gspb_css_content;
}

//////////////////////////////////////////////////////////////////
// CSS minify
//////////////////////////////////////////////////////////////////
if (!function_exists('gs_quick_minify_css')){ 
	function gs_quick_minify_css( $css ) {
		$css = preg_replace( '/\s+/', ' ', $css );
		$css = preg_replace( '/\/\*[^\!](.*?)\*\//', '', $css );
		$css = preg_replace( '/(,|:|;|\{|}) /', '$1', $css );
		$css = preg_replace( '/ (,|;|\{|})/', '$1', $css );
		$css = preg_replace( '/(:| )0\.([0-9]+)(%|em|ex|px|in|cm|mm|pt|pc)/i', '${1}.${2}${3}', $css );
		$css = preg_replace( '/(:| )(\.?)0(%|em|ex|px|in|cm|mm|pt|pc)/i', '${1}0', $css );
		return trim( $css );
	}
}

//////////////////////////////////////////////////////////////////
// Functions to render conditional scripts
//////////////////////////////////////////////////////////////////

// Hook: Frontend assets.
add_action('init', 'greenShift_register_scripts_blocks');
add_filter('render_block', 'greenShift_block_script_assets', 10, 2);

function greenShift_register_scripts_blocks()
{
	//lazyload
	wp_register_script(
		'gs-lazyload',
		GREENSHIFT_DIR_URL . 'libs/lazysizes/index.js',
		array(),
		'5.3.2',
		true
	);

	// aos script
	wp_register_script(
		'greenShift-aos-lib',
		GREENSHIFT_DIR_URL . 'libs/aos/aos.js',
		array(),
		'2.3.1',
		true
	);
	wp_register_script(
		'gsap-animation',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap.min.js',
		array(),
		'3.9',
		true
	);
	// scroll trigger
	wp_register_script(
		'gsap-scrolltrigger',
		GREENSHIFT_DIR_URL . 'libs/gsap/ScrollTrigger.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsapflip',
		GREENSHIFT_DIR_URL . 'libs/gsap/Flip.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsapsplittext',
		GREENSHIFT_DIR_URL . 'libs/gsap/SplitText.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsapsvgdraw',
		GREENSHIFT_DIR_URL . 'libs/gsap/DrawSVGPlugin.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsapsvgmorph',
		GREENSHIFT_DIR_URL . 'libs/gsap/MorphSVGPlugin.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsapsvgpath',
		GREENSHIFT_DIR_URL . 'libs/gsap/MotionPathPlugin.min.js',
		array('gsap-animation'),
		'3.9',
		true
	);

	// gsap init
	wp_register_script(
		'gsap-animation-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-init.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	//gsap reveal init
	wp_register_script(
		'gsap-reveal-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-reveal-init.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsap-mousemove-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-mousemove-init.js',
		array('gsap-animation'),
		'3.9',
		true
	);
	wp_register_script(
		'gsap-scrollparallax-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-scrollparallax-init.js',
		array('gsap-animation'),
		'3.9',
		true
	);

	// flip init
	wp_register_script(
		'gsap-flip-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-flip-init.js',
		array('gsap-animation', 'gsap-scrolltrigger', 'gsapflip'),
		'3.9',
		true
	);

	// sequencer init
	wp_register_script(
		'gsap-seq-init',
		GREENSHIFT_DIR_URL . 'libs/gsap/gsap-seq-init.js',
		array('gsap-animation', 'gsap-scrolltrigger'),
		'3.9',
		true
	);

	// blob animate init
	wp_register_script(
		'gs-blob-init',
		GREENSHIFT_DIR_URL . 'libs/blob/index.js',
		array('gsap-animation'),
		'1.0',
		true
	);

	// accordion
	wp_register_script(
		'gs-accordion',
		GREENSHIFT_DIR_URL . 'libs/accordion/index.js',
		array(),
		'1.0',
		true
	);

	// toc
	wp_register_script(
		'gs-toc',
		GREENSHIFT_DIR_URL . 'libs/toc/index.js',
		array(),
		'1.0',
		true
	);

	// swiper
	wp_register_script(
		'swiper',
		GREENSHIFT_DIR_URL . 'libs/swiper/swiper-bundle.min.js',
		array(),
		'7.3.3',
		true
	);
	wp_register_script(
		'gs-swiper-init',
		GREENSHIFT_DIR_URL . 'libs/swiper/init.js',
		array('swiper'),
		'7.3.3',
		true
	);
	wp_register_style('swiper', GREENSHIFT_DIR_URL . 'libs/swiper/swiper-bundle.min.css', array(), '7.3.3');

	// tabs
	wp_register_script(
		'gstabs',
		GREENSHIFT_DIR_URL . 'libs/tabs/tabs.js',
		array(),
		'1.0',
		true
	);

	// toggler
	wp_register_script(
		'gstoggler',
		GREENSHIFT_DIR_URL . 'libs/toggler/index.js',
		array(),
		'1.0',
		true
	);

	// video
	wp_register_script(
		'gsvideo',
		GREENSHIFT_DIR_URL . 'libs/video/index.js',
		array(),
		'1.0',
		true
	);

	// lightbox
	wp_register_script(
		'gslightbox',
		GREENSHIFT_DIR_URL . 'libs/lightbox/simpleLightbox.min.js',
		array(),
		'1.0',
		true
	);
	wp_register_style('gslightbox', GREENSHIFT_DIR_URL . 'libs/swiper/simpleLightbox.min.css', array(), '1.0');

	// counter
	wp_register_script(
		'gscounter',
		GREENSHIFT_DIR_URL . 'libs/counter/index.js',
		array(),
		'1.0',
		true
	);

	// countdown
	wp_register_script(
		'gscountdown',
		GREENSHIFT_DIR_URL . 'libs/countdown/index.js',
		array(),
		'1.0',
		true
	);

	//animated text
	wp_register_script(
		'gstextanimate',
		GREENSHIFT_DIR_URL . 'libs/animatedtext/index.js',
		array(),
		'1.0',
		true
	);

	//Model viewer
	wp_register_script(
		'gsmodelviewer',
		GREENSHIFT_DIR_URL . 'libs/modelviewer/model-viewer.min.js',
		array(),
		'1.9.2',
		true
	);
	wp_register_script(
		'gsmodelfocus',
		GREENSHIFT_DIR_URL . 'libs/modelviewer/focus-visible.js',
		array(),
		'1.9.2',
		true
	);
	wp_register_script(
		'gsmodelinit',
		GREENSHIFT_DIR_URL . 'libs/modelviewer/index.js',
		array('gsmodelviewer', 'gsmodelfocus'),
		'1.0',
		true
	);
	wp_localize_script(
		'gsmodelinit',
		'gs_model_params',
		array(
			'pluginURL' => GREENSHIFT_DIR_URL
		)
	);

	//register blocks on server side with block.json
	register_block_type(__DIR__ . '/blockrender/accordion');
	register_block_type(__DIR__ . '/blockrender/accordionitem');
	register_block_type(__DIR__ . '/blockrender/animation-container');
	register_block_type(__DIR__ . '/blockrender/blob');
	register_block_type(__DIR__ . '/blockrender/column');
	register_block_type(__DIR__ . '/blockrender/container');
	register_block_type(__DIR__ . '/blockrender/flipstate');
	register_block_type(__DIR__ . '/blockrender/counter');
	register_block_type(__DIR__ . '/blockrender/countdown');
	register_block_type(__DIR__ . '/blockrender/heading');
	register_block_type(__DIR__ . '/blockrender/icon-box');
	register_block_type(__DIR__ . '/blockrender/iconList');
	register_block_type(__DIR__ . '/blockrender/image');
	register_block_type(__DIR__ . '/blockrender/infobox');
	register_block_type(__DIR__ . '/blockrender/progressbar');
	register_block_type(__DIR__ . '/blockrender/row');
	register_block_type(__DIR__ . '/blockrender/svg-shape');
	register_block_type(__DIR__ . '/blockrender/swiper');
	register_block_type(__DIR__ . '/blockrender/swipe');
	register_block_type(__DIR__ . '/blockrender/tab');
	register_block_type(__DIR__ . '/blockrender/tabs');
	register_block_type(__DIR__ . '/blockrender/titlebox');
	register_block_type(__DIR__ . '/blockrender/toc');
	register_block_type(__DIR__ . '/blockrender/toggler');
	register_block_type(__DIR__ . '/blockrender/video');
	register_block_type(__DIR__ . '/blockrender/modelviewer');


	//Ajax register
	add_action( 'wp_ajax_gscheck_youtube_url', 'gscheck_youtube_url' );
}

function gscheck_youtube_url(){
	$url = $_POST['url'];
	$max = wp_safe_remote_head($url);
	wp_send_json_success( wp_remote_retrieve_response_code($max) );
}

function greenShift_block_script_assets($html, $block)
{
	// phpcs:ignore

	//Main styles for blocks are loaded via Redux. Can be found in src/customJS/editor/store/index.js and src/gspb-library/helpers/reusable_block_css/index.js

	if(!is_admin()){

		// aos script
		if (!empty($block['attrs']['animation']['type']) || !empty($block['attrs']['shapeDivider']['topShape']['animate']) || !empty($block['attrs']['shapeDivider']['bottomShape']['animate'])) {
			wp_enqueue_script('greenShift-aos-lib');
			// init aos library
			wp_add_inline_script(
				'greenShift-aos-lib',
				"window.addEventListener('DOMContentLoaded', function() {
						(function() {
							AOS.init();
						})();
					});"
			);
		}
	
		// looking lazy load
		if ($block['blockName'] === 'greenshift-blocks/image') {
	
			if (!empty($block['attrs']) && isset($block['attrs']['additional']) && $block['attrs']['additional'] == 'lazyload') {
				wp_enqueue_script('gs-lazyload');
			}
		}
	
		// looking for gsap animation.
		if ($block['blockName'] === 'greenshift-blocks/animation-container') {
			wp_enqueue_script('gsap-animation');
			wp_enqueue_script('gsap-scrolltrigger');
	
			// looking for gsap libraries 
			if (!empty($block['attrs']) && isset($block['attrs']['animation_type'])) {
	
				if ($block['attrs']['animation_type'] === 'text_transformations') {
					wp_enqueue_script('gsapsplittext');
				}
				if ($block['attrs']['animation_type'] === 'svg_line_draw') {
					wp_enqueue_script('gsapsvgdraw');
				}
				if ($block['attrs']['animation_type'] === 'svg_motion_path') {
					wp_enqueue_script('gsapsvgmorph');
				}
				if ($block['attrs']['animation_type'] === 'svg_morph') {
					wp_enqueue_script('gsapsvgpath');
				}
			}

			if (!empty($block['attrs']) && isset($block['attrs']['reveal_enabled'])) {
				wp_enqueue_script('gsap-reveal-init');
			}
			if (!empty($block['attrs']) && isset($block['attrs']['scroll_parallax_enabled'])) {
				wp_enqueue_script('gsap-scrollparallax-init');
			}
			if (!empty($block['attrs']) && isset($block['attrs']['mouse_move_enabled'])) {
				wp_enqueue_script('gsap-mousemove-init');
			}
			
			$attributearray = array(               
			"x",
			"y",
			"z",
			"xo",
			"yo",
			"r",
			"rx",
			"ry",
			"s",
			"sx",
			"sy",
			"o",
			"width",
			"height",
			"background",
			"origin",
			"text",
			"stagger",
			"stdelay",
			"path",
			"path_align",
			"path_orient",
			"path_align_x",
			"path_align_y",
			"path_start",
			"path_end",
			"morphend",
			"morphstart",
			"morphorigin", 
			"multiple_animation", 
			"delay",
			"yoyo",
			"loop",
			"repeatdelay",
			"strandom",
			"stchild",
			"customtrigger",
			"customobject",
			"triggerstart",
			"triggerend",
			"triggerscrub",
			"pinned",
			"pinspace",
			"triggeraction",
			"triggersnap",
			"batchint");

			foreach ($attributearray as $attributeitem){
				if(!empty($block['attrs'][$attributeitem])){
					wp_enqueue_script('gsap-animation-init');
					break;
				}
			}
		
			// gsap init
		}
		// looking for gsap Flip
		if ($block['blockName'] === 'greenshift-blocks/flipstate') {
			wp_enqueue_script('gsap-flip-init');
		}
		// looking for gsap sequencer
		if ($block['blockName'] === 'greenshift-blocks/sequencer') {
			wp_enqueue_script('gsap-seq-init');
		}
	
		// looking for blob animation
		if ($block['blockName'] === 'greenshift-blocks/blob') {
			wp_enqueue_script('gsap-animation');
			wp_enqueue_script('gs-blob-init');
		}
	
		// looking for accordion
		if ($block['blockName'] === 'greenshift-blocks/accordion') {
			wp_enqueue_script('gs-accordion');
		}
	
		// looking for toc
		if ($block['blockName'] === 'greenshift-blocks/toc') {
			wp_enqueue_script('gs-toc');
		}
		// looking for toggler
		if ($block['blockName'] === 'greenshift-blocks/toggler') {
			wp_enqueue_script('gstoggler');
		}
		// looking for counter
		if ($block['blockName'] === 'greenshift-blocks/counter') {
			wp_enqueue_script('gscounter');
		}

		// looking for countdown
		if ($block['blockName'] === 'greenshift-blocks/countdown') {
			wp_enqueue_script('gscountdown');
		}
	
		// looking for swiper
		if ($block['blockName'] === 'greenshift-blocks/swiper') {
			wp_enqueue_script('swiper');
			wp_enqueue_script('gs-swiper-init');
		}

		// looking for tabs
		if ($block['blockName'] === 'greenshift-blocks/tabs') {
			if(isset( $block['attrs']['swiper'])){
                wp_enqueue_style('swiper');
                wp_enqueue_script('swiper');
            }
			wp_enqueue_script('gstabs');
		}

		// looking for animated text
		if ($block['blockName'] === 'greenshift-blocks/heading') {
			if(isset( $block['attrs']['enableanimate'])){
                wp_enqueue_script('gstextanimate');
            }
		}

		// looking for 3d modelviewer
		if ($block['blockName'] === 'greenshift-blocks/modelviewer') {
            wp_enqueue_script('gsmodelviewer');
            wp_enqueue_script('gsmodelfocus');
            wp_enqueue_script('gsmodelinit');
		}

		//looking for video
        if( $block['blockName'] === 'greenshift-blocks/video' ){
			wp_enqueue_script('gsvideo');
            if( $block['attrs']['provider'] === "vimeo" ){
                wp_enqueue_script( 'vimeo-player', 'https://player.vimeo.com/api/player.js', array(), true, '1.0' );
            }
            if( isset($block['attrs']['overlayLightbox']) && $block['attrs']['overlayLightbox'] ){
                wp_enqueue_style( 'gslightbox');
                wp_enqueue_script( 'gslightbox' );
            }
        }
	
		if (!empty($block['attrs']) && isset($block['attrs']['animation']['usegsap'])) {
			wp_enqueue_script('gsap-animation');
			wp_enqueue_script('gsap-scrolltrigger');
			wp_enqueue_script('gsap-animation-init');
		}
		if (!empty($block['attrs']) && isset($block['attrs']['animatesvg'])) {
			wp_enqueue_script('gsap-animation');
			wp_enqueue_script('gsap-scrolltrigger');
			wp_enqueue_script('gsapsvgdraw');
			wp_enqueue_script('gsap-animation-init');
		}
		if(isset( $block['attrs']['inlineCssStyles'])){
			$dynamic_style = '<style scoped>' . wp_kses_post($block['attrs']['inlineCssStyles']) . '</style>';
			$dynamic_style = gspb_get_final_css($dynamic_style);
			$dynamic_style = gs_quick_minify_css($dynamic_style);
			$html = $html.$dynamic_style;
		}
	}


	return $html;
}

//////////////////////////////////////////////////////////////////
// Enqueue Gutenberg block assets for backend editor.
//////////////////////////////////////////////////////////////////

// Hook: Editor assets.
add_action('enqueue_block_editor_assets', 'greenShift_editor_assets');

function greenShift_editor_assets()
{
	// phpcs:ignor

	$index_asset_file = include(GREENSHIFT_DIR_PATH . 'build/index.asset.php');
	$library_asset_file = include(GREENSHIFT_DIR_PATH . 'build/gspbLibrary.asset.php');

	// gspb library script
	wp_register_script(
		'greenShift-library-script',
		GREENSHIFT_DIR_URL . 'build/gspbLibrary.js',
		array('wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-data', 'wp-plugins', 'wp-edit-post'),
		$library_asset_file['version'],
		false
	);

	// Custom Editor JavaScript
	wp_register_script(
		'greenShift-editor-js',
		GREENSHIFT_DIR_URL . 'build/gspbCustomEditor.js',
		array('greenShift-library-script', 'jquery', 'wp-data'),
		$index_asset_file['version'],
		true
	);

	wp_localize_script(
		'greenShift-editor-js',
		'greenShift_params',
		array(
			'ajaxUrl' => admin_url('admin-ajax.php'),
			'pluginURL' => GREENSHIFT_DIR_URL
		)
	);

	// Blocks Assets Scripts
	wp_enqueue_script(
		'greenShift-block-js', // Handle.
		GREENSHIFT_DIR_URL . 'build/index.js',
		array('greenShift-editor-js', 'greenShift-library-script', 'wp-block-editor', 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-data'),
		$index_asset_file['version'],
		true
	);
	

	// Styles.

	// gspb library css
	wp_register_style(
		'greenShift-library-editor',
		GREENSHIFT_DIR_URL . 'build/gspbLibrary.css',
		'',
		$library_asset_file['version']
	);

	wp_register_style(
		'greenShift-icons',
		GREENSHIFT_DIR_URL . 'libs/icons/style.css',
		'',
		$library_asset_file['version']
	);

	wp_enqueue_style(
		'greenShift-block-css', // Handle.
		GREENSHIFT_DIR_URL . 'build/index.css', // Block editor CSS.
		array('greenShift-library-editor', 'wp-edit-blocks', 'greenShift-icons'),
		$index_asset_file['version']
	);

	// Animation Library
	//wp_enqueue_style(
		//'greenShift-aos-style',
		//GREENSHIFT_DIR_URL . 'libs/aos/aos.css'
	//);

	// aos script
	wp_enqueue_script('greenShift-aos-lib');

	// gsap animation
	wp_enqueue_script('gsap-animation');
	wp_enqueue_script('gsap-scrolltrigger');
	wp_enqueue_script('gsapsplittext');
	wp_enqueue_script('gsapsvgdraw');
	wp_enqueue_script('gsapsvgpath');
	wp_enqueue_script('gsapsvgmorph');
	wp_enqueue_script('gsapflip');
	wp_enqueue_script('gsap-flip-init');
	wp_enqueue_script('gsap-seq-init');

	// gsap init
	wp_enqueue_script('gsap-animation-init');
	wp_enqueue_script('gsap-reveal-init');
	wp_enqueue_script('gsap-scrollparallax-init');
	wp_enqueue_script('gsap-mousemove-init');

	//animated text
	wp_enqueue_script('gstextanimate');
}

//////////////////////////////////////////////////////////////////
// Helper Functions to save conditional assets to meta
//////////////////////////////////////////////////////////////////

// Meta Data For CSS Post.
function gspb_register_post_meta()
{
	register_meta(
		'post',
		'gspb_post_css',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_meta(
		'wp_block',
		'gspb_reusable_block_css',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
}

add_action('init', 'gspb_register_post_meta', 10);

if (!empty($gspb_css_save_method) && $gspb_css_save_method == 'file') {
	add_action('wp_head', 'gspb_enqueue_page_style');
}
else {
	add_action('wp_enqueue_scripts', 'gspb_save_inline_css');
}

function gspb_enqueue_page_style()
{
	$gspb_post_id          = get_queried_object_id();
	$gspb_css_content = get_post_meta($gspb_post_id, 'gspb_post_css', true);

	$gspb_saved_css_content = gspb_get_final_css($gspb_css_content);

	$final_css = $gspb_saved_css_content;

	$upload_dir = wp_upload_dir();

	require_once ABSPATH . 'wp-admin/includes/file.php';
	global $wp_filesystem;
	$dir = trailingslashit($upload_dir['basedir']) . 'GreenShift/'; // Set storage directory path

	WP_Filesystem(); // WP file system

	if (!$wp_filesystem->is_dir($dir)) {
		$wp_filesystem->mkdir($dir);
	}

	$gspb_css_filename = 'style-' . $gspb_post_id . '.css';

	if (!$wp_filesystem->put_contents($dir . $gspb_css_filename, $final_css)) {
		throw new Exception(__('CSS not saved due the permission!!!', 'greenshift'));
	}

	wp_register_style('gspb_single_style', $upload_dir['baseurl'] . '/GreenShift/style-' . $gspb_post_id . '.css?v=' . time(), array(), '1.0.0', 'all');
	wp_enqueue_style('gspb_single_style');
}

function gspb_save_inline_css()
{
	// Get the css registred for the post
	$post_id          = get_queried_object_id();
	$gspb_css_content = get_post_meta($post_id, 'gspb_post_css', true);

	$gspb_saved_css_content = gspb_get_final_css($gspb_css_content);

	$final_css = $gspb_saved_css_content;

	wp_register_style('greenshift-post-css', false);
	wp_enqueue_style('greenshift-post-css');
	wp_add_inline_style('greenshift-post-css', $final_css);
}

//////////////////////////////////////////////////////////////////
// Global styles init
//////////////////////////////////////////////////////////////////
add_action('enqueue_block_assets', 'gs_global_variables');
function gs_global_variables() {

	//root styles
	$options = get_option( 'gspb_global_settings');
	$gs_global_css = ':root{--gs-type-one-size:36px;--gs-type-one-lineheight:44px;--gs-type-two-size:30px;--gs-type-two-lineheight:38px;--gs-type-three-size:24px;--gs-type-three-lineheight:30px;--gs-type-four-size:20px;--gs-type-four-lineheight:28px;--gs-type-five-size:15px;--gs-type-five-lineheight:24px;--gs-colorone:#2184f9;--gs-colortwo:#e90000;--gs-colorthree:#2adb32;--gs-colorfour:#696cff;--gs-colorfive:#ff9800}';
	if(!empty($options['globalcss'])){
		$gs_global_css = $options['globalcss'].$gs_global_css;
	}
	if($gs_global_css){
		wp_register_style('greenshift-global-css', false);
		wp_enqueue_style('greenshift-global-css');
		wp_add_inline_style('greenshift-global-css',$gs_global_css);

	}

}

//////////////////////////////////////////////////////////////////
// Template Library
//////////////////////////////////////////////////////////////////

const TEMPLATE_SERVER_URL = 'https://store.blockypage.com';

add_action('wp_ajax_gspb_get_layouts', 'gspb_get_all_layouts');
add_action('wp_ajax_gspb_get_layout_by_id', 'gspb_get_layout');
add_action('wp_ajax_gspb_get_categories', 'gspb_get_categories');

function gspb_get_all_layouts()
{
	$get_args = array('timeout' => 120);
	$category = $_POST['category_id'];
	$apiUrl   = TEMPLATE_SERVER_URL . '/wp-json/wp/v2/posts/?_embed&filter[category_name]=' . $category . '&per_page=100';
	$response = wp_remote_get($apiUrl, $get_args);
	if (is_array($response)) {
		$body = $response['body'];
	}
	echo $body;
	wp_die();
}

function gspb_get_layout()
{
	$get_args = array(
		'timeout'   => 120,
		'sslverify' => false,
	);
	$id       = $_POST['gspb_layout_id'];
	$apiUrl   = TEMPLATE_SERVER_URL . '/wp-json/greenshift/v1/layout/' . $id;
	$response = wp_remote_get($apiUrl, $get_args);
	if (is_array($response)) {
		$body = $response['body'];
	}
	echo $body;
	wp_die();
}

function gspb_get_categories()
{
	$get_args = array(
		'timeout'   => 120,
		'sslverify' => false,
	);
	$id       = $_POST['category_id'];
	$url      = $_POST['url'];
	$apiUrl   = TEMPLATE_SERVER_URL . '/wp-json/wp/v2/categories?parent=' . $id;
	$response = wp_remote_get($apiUrl, $get_args);
	if (is_array($response)) {
		$body = $response['body'];
	}
	echo $body;
	wp_die();
}

//////////////////////////////////////////////////////////////////
// REST routes to save and get settings
//////////////////////////////////////////////////////////////////

add_action('rest_api_init', 'gspb_register_route');

function gspb_register_route()
{

	register_rest_route(
		'greenshift/v1',
		'/global_settings/',
		array(
			array(
				'methods'             => 'GET',
				'callback'            => 'gspb_get_global_settings',
				'permission_callback' => function () {
					return current_user_can('edit_posts');
				},
				'args'                => array(),
			),
			array(
				'methods'             => 'POST',
				'callback'            => 'gspb_update_global_settings',
				'permission_callback' => function () {
					return current_user_can('edit_posts');
				},
				'args'                => array(),
			),
		)
	);

}

function gspb_get_global_settings()
{

	try {

		$settings = get_option('gspb_global_settings');

		return array(
			'success'  => true,
			'settings' => $settings,
		);
	} catch (Exception $e) {
		return array(
			'success' => false,
			'message' => $e->getMessage(),
		);
	}
}

function gspb_update_global_settings($request)
{

	try {
		$params = $request->get_params();

		if (get_option('gspb_global_settings') === false) {
			add_option('gspb_global_settings', $params);
		} else {
			update_option('gspb_global_settings', $params);
		}

		$settings = get_option('gspb_global_settings');
		return json_encode(array(
			'success' => true,
			'message' => 'Global settings updated!',
		));
	} catch (Exception $e) {
		return json_encode(array(
			'success' => false,
			'message' => $e->getMessage(),
		));
	}
}

//////////////////////////////////////////////////////////////////
// USDZ support until WP will have it
//////////////////////////////////////////////////////////////////
function gs_webp_upload_mimes($existing_mimes) {
	$existing_mimes['glb']  = 'application/octet-stream';
    $existing_mimes['usdz']  = 'application/octet-stream';
	$existing_mimes['gltf']  = 'text/plain';
    return $existing_mimes;
}
add_filter('mime_types', 'gs_webp_upload_mimes');
