"use strict";
let videos = document.getElementsByClassName('gs-video-element');
for (let video of videos) {
    var type = video.dataset.provider,
        isOverlay= video.dataset.overlay,
        isLightbox = video.dataset.lightbox,
        overlay = video.nextSibling,
        player;
    if( isOverlay === "false" ){
        switch(type){
            case 'video':
                const body = document.body;
                body.addEventListener("mouseover", getGSHostedVideo( video ), {once:true});
                body.addEventListener("touchmove", getGSHostedVideo( video ), {once:true});
                body.addEventListener("scroll", getGSHostedVideo( video ), {once:true});
                body.addEventListener("keydown", getGSHostedVideo( video ), {once:true});
                //getGSHostedVideo( video );
                break;
            case 'youtube':
                getGSYoutubeVideo( video );
                break;
            case 'vimeo':
                getGSVimeoVideo( video );
                break;
        }
    } else {
        overlay.onclick = function(){
            var video = this.previousSibling,
                type = this.dataset.type,
                isLightbox = this.dataset.lightbox,
                overlay = this;
            if( isLightbox !== "true" ){
                switch(type){
                    case 'video':
                        var el = getGSHostedVideo( video );
                        el.play();
                        break;
                    case 'youtube':
                        getGSYoutubeVideo( video );
                        break;
                    case 'vimeo':
                        getGSVimeoVideo( video );
                        break;
                }
                this.remove();
            } else {
                SimpleLightbox.open({
                    content: video,
                    elementClass: 'gs-video-popup',
                    beforeClose: function(e){
                        overlay.parentNode.insertBefore(video, overlay);
                    },
                });
                switch(type){
                    case 'video':
                        var el = getGSHostedVideo( video );
                        el.play();
                        break;
                    case 'youtube':
                        getGSYoutubeVideo( video );
                        break;
                    case 'vimeo':
                        getGSVimeoVideo( video );
                        break;
                }
            }
        }
    }
}

function getGSHostedVideo( video ) {
    var el = document.createElement("video");
    el.setAttribute('class', 'gs-video-element');
    el.setAttribute('src', video.dataset.src);
    el.setAttribute('poster', video.dataset.poster);
    el.autoplay = video.dataset.autoplay === "true" ? true : false;
    el.playsInline = video.dataset.playsinline === "true" ? true : false;
    el.controls = video.dataset.controls === "true" ? true : false;
    el.loop = video.dataset.loop === "true" ? true : false;
    el.muted = video.dataset.mute === "true" ? true : false;
    video.replaceWith(el);
    if(video.dataset.autoplay === "true"){
        el.play();
    }
    return el;
}
function getGSVideoIDFromURL(url, regex) {
    var videoIDParts = url.match(regex);
    return videoIDParts && videoIDParts[1];
}
function getGSYoutubeRegex() {
    return /^(?:https?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?vi?=|(?:embed|v|vi|user)\/))([^?&"'>]+)/;
}
function getGSYoutubeVideo( video ) {
    var src = video.dataset.src,
        videoID = getGSVideoIDFromURL(src, getGSYoutubeRegex());
    var url = '//www.youtube.com/embed/'
        + videoID
        + "?autoplay=" + (video.dataset.autoplay === "true" ? "1" : "0")
        + '&loop=' + (video.dataset.loop === "true" ? "1" : "0")
        + '&playsinline=' + (video.dataset.playsinline === "true" ? "1" : "0")
        + '&controls=' + (video.dataset.controls === "true" ? "1" : "0")
        + '&modestbranding=' + (video.dataset.modestbranding === "true" ? "1" : "0")
        + '&rel=' + (video.dataset.rel === "true" ? "1" : "0")
        + '&mute=' + (video.dataset.mute === "true" ? "1" : "0")
        + (video.dataset.start && video.dataset.loop === "false" ? "&start=" + video.dataset.start : "")
        + (video.dataset.end && video.dataset.loop === "false" ? "&end=" + video.dataset.end : "");
    video.setAttribute('src', url);
}
function getGSVimeoRegex() {
    return /^(?:https?:\/\/)?(?:www|player\.)?(?:vimeo\.com\/)?(?:video\/|external\/)?(\d+)([^.?&#"'>]?)/;
}
function getGSVimeoVideo( video ) {
    var src = video.dataset.src,
        videoID = getGSVideoIDFromURL(src, getGSVimeoRegex());
    var options = {
        id: videoID,
        autoplay: video.dataset.autoplay === "true" ? 1 : 0,
        loop: video.dataset.loop === "true" ? 1 : 0,
        playsinline: video.dataset.playsinline === "true" ? 1 : 0,
        muted: video.dataset.mute === "true" ? 1 : 0,
        controls: video.dataset.controls === "true" ? 1 : 0,
        title: video.dataset.title === "true" ? 1 : 0,
        portrait: video.dataset.portrait === "true" ? 1 : 0,
        byline: video.dataset.byline === "true" ? 1 : 0,
    };
    player = new Vimeo.Player(video, options);
    ! isNaN(video.dataset.start) && player.setCurrentTime( parseInt(video.dataset.start) );
}