<?php
// Exit if accessed directly
if (!defined('ABSPATH')) {
	exit;
}

if (!class_exists('GreenShift_Settings')) {

	class GreenShift_Settings
	{

		public function __construct()
		{
			add_action('admin_menu', array($this, 'greenshift_admin_page'));
		}

		public function greenshift_admin_page()
		{

			$parent_slug = 'greenshift_dashboard';

			add_menu_page(
				esc_html__('GreenShift'),
				esc_html__('GreenShift'),
				'manage_options',
				$parent_slug,
				array($this, 'welcome_page'),
				plugin_dir_url( __FILE__ ) . 'libs/gspbLogo.svg',
				20
			);

			add_submenu_page(
				$parent_slug,
				esc_html__('Settings'),
				esc_html__('Settings'),
				'manage_options',
				'greenshift',
				array($this, 'settings_page')
			);
		}

		public function welcome_page()
		{
?>
			<div class="wrap gspb_welcome_div_container">
				<style>
					.wrap {
						background: white;
						max-width: 900px;
						margin: 2.5em auto;
						border: 1px solid #dbdde2;
						box-shadow: 0 10px 20px #ececec;
						text-align: center
					}

					.wrap .notice,
					.wrap .error {
						display: none
					}

					.wrap h2 {
						font-size: 2em;
						margin-bottom: 1em;
						font-weight: bold
					}

					.gs-introtext {
						font-size: 14px;
						max-width: 500px;
						margin: 0 auto 50px auto
					}

					.gs-intro-video iframe {
						box-shadow: 10px 10px 20px rgb(0 0 0 / 15%);
					}

					.gs-intro-video {
						margin-bottom: 80px
					}

					.wrap h1 {
						text-align: left;
						padding: 15px 20px;
						margin: -1px -1px 60px -1px;
						font-size: 13px;
						font-weight: bold;
						text-transform: uppercase;
						box-shadow: 0 3px 8px rgb(0 0 0 / 5%);
					}

					.gs-padd {
						padding: 25px
					}
				</style>
				<h1><?php esc_html_e("Getting Started");?></h1>
				<div class="gs-padd">
					<p class="gs-introtext"><?php esc_html_e("Thank you for using Greenshift. For any bug report, please, contact us "); ?> <a href="http://codecanyon.net/user/sizam#contact"><?php esc_html_e("through the contact form"); ?></a></p>
					<div class="gs-intro-video"></div>
				</div>
			</div>
		<?php
		}

		public function settings_page()
		{

			if (!current_user_can('manage_options')) {
				wp_die('Unauthorized user');
			}

			// Get the active tab from the $_GET param
			$default_tab = null;
			$tab         = isset($_GET['tab']) ? $_GET['tab'] : $default_tab;

		?>
			<div class="wrap">
			<style>
					.wrap {
						background: white;
						max-width: 900px;
						margin: 2.5em auto;
						border: 1px solid #dbdde2;
						box-shadow: 0 10px 20px #ececec;
						text-align: center
					}

					.wrap .notice,
					.wrap .error {
						display: none
					}

					.wrap h2 {
						font-size: 2em;
						margin-bottom: 1em;
						font-weight: bold;
						padding: 15px;
    					background: #f4f4f4;
					}

					.gs-introtext {
						font-size: 14px;
						max-width: 500px;
						margin: 0 auto 50px auto
					}

					.gs-intro-video iframe {
						box-shadow: 10px 10px 20px rgb(0 0 0 / 15%);
					}

					.gs-intro-video {
						margin-bottom: 80px
					}

					.wrap h1 {
						text-align: left;
						padding: 15px 20px;
						margin: -1px -1px 60px -1px;
						font-size: 13px;
						font-weight: bold;
						text-transform: uppercase;
						box-shadow: 0 3px 8px rgb(0 0 0 / 5%);
					}

					.gs-padd {
						padding: 25px;
						text-align: left;
						background-color: #fbfbfb
					}
					.rtl .gs-padd{text-align: right}
					.wp-core-ui .button-primary{background-color: #2184f9}
					.nav-tab-active, .nav-tab-active:focus, .nav-tab-active:focus:active, .nav-tab-active:hover {
    					border-bottom: 1px solid #fbfbfb;
    					background: #fbfbfb;
					}
					.nav-tab-wrapper{padding-left:20px}
				</style>
				<h1><?php echo esc_html(get_admin_page_title()); ?></h1>
				<!-- Here are our tabs -->
				<nav class="nav-tab-wrapper">
					<a href="?page=greenshift" class="nav-tab 
					<?php
					if ($tab === null) :
					?>
						nav-tab-active<?php endif; ?>"> <?php esc_html_e("General");?> </a>
					<a href="?page=greenshift&tab=save_css" class="nav-tab 
					<?php
					if ($tab === 'save_css') :
					?>
						nav-tab-active<?php endif; ?>"><?php esc_html_e("Save CSS");?></a>
					<a href="?page=greenshift&tab=breakpoints" class="nav-tab 
					<?php
					if ($tab === 'breakpoints') :
					?>
						nav-tab-active<?php endif; ?>"><?php esc_html_e("Breakpoints");?></a>
				</nav>

				<div class="tab-content gs-padd">
					<?php
					switch ($tab):
						case 'save_css':
							if (isset($_POST['gspb_save_settings'])) {
								if (!wp_verify_nonce($_POST['gspb_settings_field'], 'gspb_settings_page_action')) {
									esc_html_e("Sorry, your nonce did not verify.");
									return;
								}
								update_option('gspb_css_save', $_POST['gspb_settings_option']);
							}

							$css_tsyle_option = get_option('gspb_css_save');
					?>
							<div class="gspb_settings_form">
								<form method="POST">
									<?php wp_nonce_field('gspb_settings_page_action', 'gspb_settings_field'); ?>
									<table class="form-table">
										<tr>
											<th> <label for="css_system"><?php esc_html_e("Css location");?></label> </th>
											<td>
												<select name="gspb_settings_option">
													<option value="inline" <?php echo $css_tsyle_option == 'inline' ? 'selected' : null; ?>><?php esc_html_e("Inline");?> </option>
													<option value="file" <?php echo $css_tsyle_option == 'file' ? 'selected' : null; ?>> <?php esc_html_e("File system");?> </option>
												</select>
											</td>
										</tr>
									</table>

									<input type="submit" name="gspb_save_settings" value="<?php esc_html_e("Save settings");?>" class="button button-primary button-large">
								</form>
							</div>
						<?php
							break;
						case 'breakpoints':
							$global_settings = get_option('gspb_global_settings');

							if (isset($_POST['gspb_save_settings']) && isset($_POST['gspb_settings_field']) && wp_verify_nonce($_POST['gspb_settings_field'], 'gspb_settings_page_action')) {
								$breakpoints = array(
									"mobile" =>  $_POST['mobile'],
									"tablet" =>  $_POST['tablet'],
									"desktop" =>  $_POST['desktop']
								);
								$global_settings['breakpoints'] = $breakpoints;
								update_option('gspb_global_settings', $global_settings);
							}
						?>
							<form method="POST" class="greenshift_form">
								<?php wp_nonce_field('gspb_settings_page_action', 'gspb_settings_field'); ?>
								<table class="form-table">

									<tr>
										<td> <?php esc_html_e("Mobile");?> </td>
										<td> <input name="mobile" type="text" value="<?php if (isset($global_settings['breakpoints']['mobile'])) {
											echo $global_settings['breakpoints']['mobile'];
										}  ?>" placeholder="576" /> </td>
									</tr>
									<tr>
										<td> <?php esc_html_e("Tablet");?> </td>
										<td> <input name="tablet" type="text" value="<?php if (isset($global_settings['breakpoints']['tablet'])) {
											echo $global_settings['breakpoints']['tablet'];
										} ?>" placeholder="768" /> </td>
									</tr>
									<tr>
										<td> <?php esc_html_e("Desktop");?> </td>
										<td> <input name="desktop" type="text" value="<?php if (isset($global_settings['breakpoints']['desktop'])) {
											echo $global_settings['breakpoints']['desktop'];
										} ?>" placeholder="992" /> </td>
									</tr>
								</table>
								<input type="submit" name="gspb_save_settings" value="Save" class="button button-primary button-large">
							</form>
					<?php
							break;
						default:
						?>
							<h2><?php esc_html_e("General Settings");?></h2>
								<?php esc_html_e("You can assign global presets and other settings in Post edit area when you click on G button in header toolbar");?>
							<?php
							break;
					endswitch;
					?>
				</div>
			</div>
			<?php

			?>
<?php
		}
	}
}

?>